#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_IS_NLTZ_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_IS_NLTZ_HPP_INCLUDED

#include <nt2/predicates/include/functions/scalar/is_nltz.hpp>

#endif
